pub struct DirsOptionsArgs {
pub data_dir: Option<PathBuf>,
pub chapters: Option<PathBuf>,
pub mangas: Option<PathBuf>,
pub covers: Option<PathBuf>,
}Fields
data_dir: Option<PathBuf>data directory path
Default: “output”
chapters: Option<PathBuf>chapter directory relative to data_dir (you can put an absolute path if you wanted to)
mangas: Option<PathBuf>manga directory relative to data_dir (you can put an absolute path if you wanted to)
covers: Option<PathBuf>covers directory relative to data_dir (you can put an absolute path if you wanted to)